==> nextcloud-app-mail-5.1.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/oc.js <==
OC.L10N.register(
    "mail",
    {
    "Important mail" : "Mail important",
    "No message found yet" : "Pas cap de messatge trobat",
    "Unread mail" : "Mail pas legit",
    "Important" : "Important",
    "Work" : "Professional(a)",
    "Personal" : "Personal",
    "Mail" : "Mail",
    "Mails" : "Mails",
    "Connecting" : "Connexion",
    "Save" : "Salvar",
    "Connect" : "Connectar",
    "Password required" : "Senhal requerit",
    "Name" : "Nom",
    "Password" : "Senhal",
    "IMAP Settings" : "Paramètres IMAP",
    "None" : "Pas cap",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Password" : "Senhal IMAP",
    "SMTP Settings" : "Paramètres SMTP",
    "SMTP Password" : "Senhal SMTP",
    "Account settings" : "Paramètres de compte",
    "Signature" : "Signatura",
    "Mail server" : "Servidor email",
    "Rename alias" : "Renomenar l’àlias",
    "Go back" : "Revenir en arrière",
    "Email address" : "Adreça mail",
    "Cancel" : "Anullar",
    "Accounts" : "Accounts",
    "General" : "Generals",
    "List" : "Tièra",
    "Register" : "S'inscriure",
    "About" : "A prepaus",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Archive" : "Archius",
    "Delete" : "Suprimir",
    "Search" : "Recercar",
    "Send" : "Mandar",
    "Refresh" : "Refrescar",
    "From" : "De",
    "Write message …" : "Escriure un messatge…",
    "Monday morning" : "Diluns matin",
    "Choose" : "Causir",
    "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
    "Confirm" : "Confirmar",
    "No messages" : "Cap de messatge",
    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
    "Favorite" : "Favorit",
    "Read" : "Legit",
    "More actions" : "Mai d’accions",
    "Back" : "Retorn",
    "All day" : "Tota la jornada",
    "Description" : "Descripcion",
    "Create" : "Crear",
    "Select" : "Select",
    "Comment" : "Comentaris",
    "Accept" : "Acceptar",
    "Decline" : "Declinar",
    "Remove" : "Suprimir",
    "Other" : "Autre",
    "Translate" : "Tradurre",
    "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
    "Move" : "Move",
    "Loading …" : "Cargament…",
    "Quota" : "Quota",
    "Folder name" : "Nom del dorsièr",
    "_{total} message_::_{total} messages_" : ["{total} messatge","{total} messatges"],
    "Delete folder" : "Suprimir dossièr",
    "Mark all as read" : "Marcar totes coma legits",
    "Rename" : "Tornar nommar",
    "Clear cache" : "Voidar l'escondedor",
    "Reply" : "Respondre",
    "Retry" : "Tornar ensajar",
    "Copy to clipboard" : "Copiar dins lo quichapapièrs",
    "Add" : "Apondre",
    "Clear" : "Escafar",
    "Close" : "Tampar",
    "Body" : "Còs",
    "Date" : "Data",
    "Tags" : "Etiquetas",
    "Custom" : "Personalizats",
    "Mark as unread" : "Marcar coma pas legit",
    "Mark as read" : "Marcar coma legit",
    "Translate message" : "Traduire lo messatge",
    "Translating" : "Traduccion",
    "Untitled event" : "Eveniment sens títol",
    "Train" : "Tren",
    "Flag" : "Drapèu",
    "Reset" : "Reïnicializar",
    "Client ID" : "ID client",
    "User" : "Utilizator",
    "Host" : "Òste",
    "Port" : "Pòrt",
    "Valid until" : "Valid fins a",
    "Certificate" : "Certificat",
    "Submit" : "Transmetre",
    "Account connected" : "Compte connectat",
    "All" : "Tot",
    "Drafts" : "Borrolhons",
    "Favorites" : "Favorits",
    "All inboxes" : "Totas las bóstias",
    "Inbox" : "Bóstia de recepcion",
    "Junk" : "Indesirables",
    "Sent" : "Mandats",
    "Trash" : "Escobilhièr",
    "Error while sharing file" : "Error pendent lo partiment del fichièr",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Message sent" : "Messatge mandat",
    "Error loading message" : "Error al moment del cargament del messatge",
    "Continue to %s" : "Contunhar cap a %s",
    "Actions" : "Accions"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-mail-5.2.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/oc.js <==
OC.L10N.register(
    "mail",
    {
    "Important mail" : "Mail important",
    "No message found yet" : "Pas cap de messatge trobat",
    "Unread mail" : "Mail pas legit",
    "Important" : "Important",
    "Work" : "Professional(a)",
    "Personal" : "Personal",
    "Mail" : "Mail",
    "Mails" : "Mails",
    "Connecting" : "Connexion",
    "Save" : "Salvar",
    "Connect" : "Connectar",
    "Password required" : "Senhal requerit",
    "Name" : "Nom",
    "Password" : "Senhal",
    "IMAP Settings" : "Paramètres IMAP",
    "None" : "Pas cap",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Password" : "Senhal IMAP",
    "SMTP Settings" : "Paramètres SMTP",
    "SMTP Password" : "Senhal SMTP",
    "Account settings" : "Paramètres de compte",
    "Signature" : "Signatura",
    "Mail server" : "Servidor email",
    "Rename alias" : "Renomenar l’àlias",
    "Go back" : "Revenir en arrière",
    "Email address" : "Adreça mail",
    "Cancel" : "Anullar",
    "Accounts" : "Accounts",
    "General" : "Generals",
    "List" : "Tièra",
    "Register" : "S'inscriure",
    "About" : "A prepaus",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Archive" : "Archius",
    "Delete" : "Suprimir",
    "Search" : "Recercar",
    "Send" : "Mandar",
    "Refresh" : "Refrescar",
    "From" : "De",
    "Write message …" : "Escriure un messatge…",
    "Monday morning" : "Diluns matin",
    "Choose" : "Causir",
    "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
    "Confirm" : "Confirmar",
    "No messages" : "Cap de messatge",
    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
    "Favorite" : "Favorit",
    "Read" : "Legit",
    "More actions" : "Mai d’accions",
    "Back" : "Retorn",
    "All day" : "Tota la jornada",
    "Description" : "Descripcion",
    "Create" : "Crear",
    "Select" : "Select",
    "Comment" : "Comentaris",
    "Accept" : "Acceptar",
    "Decline" : "Declinar",
    "Remove" : "Suprimir",
    "Today" : "Uèi",
    "Last week" : "La setmana passada",
    "Last month" : "Lo mes passat",
    "Other" : "Autre",
    "Translate" : "Tradurre",
    "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
    "Move" : "Move",
    "Folder name" : "Nom del dorsièr",
    "_{total} message_::_{total} messages_" : ["{total} messatge","{total} messatges"],
    "Loading …" : "Cargament…",
    "Delete folder" : "Suprimir dossièr",
    "Mark all as read" : "Marcar totes coma legits",
    "Rename" : "Tornar nommar",
    "Clear cache" : "Voidar l'escondedor",
    "Reply" : "Respondre",
    "Retry" : "Tornar ensajar",
    "Copy to clipboard" : "Copiar dins lo quichapapièrs",
    "Add" : "Apondre",
    "Clear" : "Escafar",
    "Close" : "Tampar",
    "Body" : "Còs",
    "Date" : "Data",
    "Tags" : "Etiquetas",
    "Custom" : "Personalizats",
    "Mark as unread" : "Marcar coma pas legit",
    "Mark as read" : "Marcar coma legit",
    "Translate message" : "Traduire lo messatge",
    "Translating" : "Traduccion",
    "Untitled event" : "Eveniment sens títol",
    "Train" : "Tren",
    "Flag" : "Drapèu",
    "Reset" : "Reïnicializar",
    "Client ID" : "ID client",
    "User" : "Utilizator",
    "Host" : "Òste",
    "Port" : "Pòrt",
    "Valid until" : "Valid fins a",
    "Certificate" : "Certificat",
    "Submit" : "Transmetre",
    "Guest" : "Convidat",
    "Group" : "Grop",
    "Shared" : "Partejat",
    "Shares" : "Partatges",
    "Account connected" : "Compte connectat",
    "All" : "Tot",
    "Drafts" : "Borrolhons",
    "Favorites" : "Favorits",
    "All inboxes" : "Totas las bóstias",
    "Inbox" : "Bóstia de recepcion",
    "Junk" : "Indesirables",
    "Sent" : "Mandats",
    "Trash" : "Escobilhièr",
    "Error while sharing file" : "Error pendent lo partiment del fichièr",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Message sent" : "Messatge mandat",
    "Error loading message" : "Error al moment del cargament del messatge",
    "Continue to %s" : "Contunhar cap a %s",
    "Actions" : "Accions"
},
"nplurals=2; plural=(n > 1);");
